==> jc-1.4.0.tar.gz: javax/net/ssl/TrustManagerFactorySpi.h <==
// public abstract class javax.net.ssl.TrustManagerFactorySpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b15e7a736226bd65 javax_net_ssl_TrustManagerFactorySpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_net_ssl_TrustManagerFactorySpi_H_
#define _JC_javax_net_ssl_TrustManagerFactorySpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_KeyStore$object;
struct _jc_javax_net_ssl_ManagerFactoryParameters$object;

// Typedefs
typedef struct _jc_javax_net_ssl_TrustManagerFactorySpi$sub_refs	_jc_javax_net_ssl_TrustManagerFactorySpi$sub_refs;
typedef struct _jc_javax_net_ssl_TrustManagerFactorySpi$sub_nonrefs	_jc_javax_net_ssl_TrustManagerFactorySpi$sub_nonrefs;
typedef struct _jc_javax_net_ssl_TrustManagerFactorySpi$refs	_jc_javax_net_ssl_TrustManagerFactorySpi$refs;
typedef struct _jc_javax_net_ssl_TrustManagerFactorySpi$nonrefs	_jc_javax_net_ssl_TrustManagerFactorySpi$nonrefs;
typedef struct _jc_javax_net_ssl_TrustManagerFactorySpi$object	_jc_javax_net_ssl_TrustManagerFactorySpi$object;

typedef const struct _jc_javax_net_ssl_TrustManagerFactorySpi$vmethods	_jc_javax_net_ssl_TrustManagerFactorySpi$vmethods;
typedef const struct _jc_javax_net_ssl_TrustManagerFactorySpi$vtable	_jc_javax_net_ssl_TrustManagerFactorySpi$vtable;
typedef const struct _jc_javax_net_ssl_TrustManagerFactorySpi$vtype	_jc_javax_net_ssl_TrustManagerFactorySpi$vtype;

// Constructors
extern void _jc_javax_net_ssl_TrustManagerFactorySpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *);

// Virtual methods
extern _jc_object_array *_jc_javax_net_ssl_TrustManagerFactorySpi$method$engineGetTrustManagers$fcf5cb4530577c21(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *);
extern void _jc_javax_net_ssl_TrustManagerFactorySpi$method$engineInit$f4925969e85ce700(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *, struct _jc_java_security_KeyStore$object *);
extern void _jc_javax_net_ssl_TrustManagerFactorySpi$method$engineInit$7d0f73d1c75dca0e(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_TrustManagerFactorySpi$method_info$engineGetTrustManagers$fcf5cb4530577c21;
extern _jc_method _jc_javax_net_ssl_TrustManagerFactorySpi$method_info$engineInit$f4925969e85ce700;
extern _jc_method _jc_javax_net_ssl_TrustManagerFactorySpi$method_info$engineInit$7d0f73d1c75dca0e;

// Virtual methods structure
struct _jc_javax_net_ssl_TrustManagerFactorySpi$vmethods {
	_jc_object_array	*(*engineGetTrustManagers$fcf5cb4530577c21)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *);
	void	(*engineInit$f4925969e85ce700)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *, struct _jc_java_security_KeyStore$object *);
	void	(*engineInit$7d0f73d1c75dca0e)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_net_ssl_TrustManagerFactorySpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_ssl_TrustManagerFactorySpi$vmethods	javax_net_ssl_TrustManagerFactorySpi;
};

// Vtype
struct _jc_javax_net_ssl_TrustManagerFactorySpi$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_TrustManagerFactorySpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_TrustManagerFactorySpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_TrustManagerFactorySpi$refs {
    _jc_javax_net_ssl_TrustManagerFactorySpi$sub_refs	javax_net_ssl_TrustManagerFactorySpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_TrustManagerFactorySpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_TrustManagerFactorySpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_ssl_TrustManagerFactorySpi$sub_nonrefs	javax_net_ssl_TrustManagerFactorySpi;
};

// Object instance structure
struct _jc_javax_net_ssl_TrustManagerFactorySpi$object {
	_jc_javax_net_ssl_TrustManagerFactorySpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_TrustManagerFactorySpi$vtype	*vtype;
	_jc_javax_net_ssl_TrustManagerFactorySpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_TrustManagerFactorySpi$vtype _jc_javax_net_ssl_TrustManagerFactorySpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_TrustManagerFactorySpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_TrustManagerFactorySpi$class_object;

#endif	/* _JC_javax_net_ssl_TrustManagerFactorySpi_H_ */

==> jc-1.4.6.tar.gz: javax/net/ssl/TrustManagerFactorySpi.h <==
// public abstract class javax.net.ssl.TrustManagerFactorySpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b15e7a736226bd65 javax_net_ssl_TrustManagerFactorySpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_net_ssl_TrustManagerFactorySpi_H_
#define _JC_javax_net_ssl_TrustManagerFactorySpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_KeyStore$object;
struct _jc_javax_net_ssl_ManagerFactoryParameters$object;

// Typedefs
typedef struct _jc_javax_net_ssl_TrustManagerFactorySpi$sub_refs	_jc_javax_net_ssl_TrustManagerFactorySpi$sub_refs;
typedef struct _jc_javax_net_ssl_TrustManagerFactorySpi$sub_nonrefs	_jc_javax_net_ssl_TrustManagerFactorySpi$sub_nonrefs;
typedef struct _jc_javax_net_ssl_TrustManagerFactorySpi$refs	_jc_javax_net_ssl_TrustManagerFactorySpi$refs;
typedef struct _jc_javax_net_ssl_TrustManagerFactorySpi$nonrefs	_jc_javax_net_ssl_TrustManagerFactorySpi$nonrefs;
typedef struct _jc_javax_net_ssl_TrustManagerFactorySpi$object	_jc_javax_net_ssl_TrustManagerFactorySpi$object;

typedef const struct _jc_javax_net_ssl_TrustManagerFactorySpi$vmethods	_jc_javax_net_ssl_TrustManagerFactorySpi$vmethods;
typedef const struct _jc_javax_net_ssl_TrustManagerFactorySpi$vtable	_jc_javax_net_ssl_TrustManagerFactorySpi$vtable;
typedef const struct _jc_javax_net_ssl_TrustManagerFactorySpi$vtype	_jc_javax_net_ssl_TrustManagerFactorySpi$vtype;

// Constructors
extern void _jc_javax_net_ssl_TrustManagerFactorySpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_javax_net_ssl_TrustManagerFactorySpi$method$engineGetTrustManagers$fcf5cb4530577c21(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *) _JC_JCNI_ATTR;
extern void _jc_javax_net_ssl_TrustManagerFactorySpi$method$engineInit$f4925969e85ce700(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *, struct _jc_java_security_KeyStore$object *) _JC_JCNI_ATTR;
extern void _jc_javax_net_ssl_TrustManagerFactorySpi$method$engineInit$7d0f73d1c75dca0e(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_TrustManagerFactorySpi$method_info$engineGetTrustManagers$fcf5cb4530577c21;
extern _jc_method _jc_javax_net_ssl_TrustManagerFactorySpi$method_info$engineInit$f4925969e85ce700;
extern _jc_method _jc_javax_net_ssl_TrustManagerFactorySpi$method_info$engineInit$7d0f73d1c75dca0e;

// Virtual methods structure
struct _jc_javax_net_ssl_TrustManagerFactorySpi$vmethods {
	_jc_object_array	*(*engineGetTrustManagers$fcf5cb4530577c21)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *) _JC_JCNI_ATTR;
	void	(*engineInit$f4925969e85ce700)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *, struct _jc_java_security_KeyStore$object *) _JC_JCNI_ATTR;
	void	(*engineInit$7d0f73d1c75dca0e)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_net_ssl_TrustManagerFactorySpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_ssl_TrustManagerFactorySpi$vmethods	javax_net_ssl_TrustManagerFactorySpi;
};

// Vtype
struct _jc_javax_net_ssl_TrustManagerFactorySpi$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_TrustManagerFactorySpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_TrustManagerFactorySpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_TrustManagerFactorySpi$refs {
    _jc_javax_net_ssl_TrustManagerFactorySpi$sub_refs	javax_net_ssl_TrustManagerFactorySpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_TrustManagerFactorySpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_TrustManagerFactorySpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_ssl_TrustManagerFactorySpi$sub_nonrefs	javax_net_ssl_TrustManagerFactorySpi;
};

// Object instance structure
struct _jc_javax_net_ssl_TrustManagerFactorySpi$object {
	_jc_javax_net_ssl_TrustManagerFactorySpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_TrustManagerFactorySpi$vtype	*vtype;
	_jc_javax_net_ssl_TrustManagerFactorySpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_TrustManagerFactorySpi$vtype _jc_javax_net_ssl_TrustManagerFactorySpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_TrustManagerFactorySpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_TrustManagerFactorySpi$class_object;

#endif	/* _JC_javax_net_ssl_TrustManagerFactorySpi_H_ */
